# Changelog

## [stormi-v0.5.0](https://github.com/pinellolab/stormi/compare/stormi-v0.4.0...stormi-v0.5.0) (2025-06-30)

### Features

* **guides:** Guide with amortization for splicing rate based on gene embeddings. ([00e20f3](https://github.com/pinellolab/stormi/commit/00e20f3bc2bb1df70d5aa96c720069a27ef05c39))
* **guides:** Guide with amortization for splicing rate based on gene embeddings. ([2c8d22b](https://github.com/pinellolab/stormi/commit/2c8d22b3f560199d17449a420017f13ead6823c4))
* **tests:** Test for amortized guide for splicing rate. ([b56b937](https://github.com/pinellolab/stormi/commit/b56b937097680dbdcde050f6c88627f4d428c499))
* **tests:** Test for amortized guide for splicing rate. ([6153350](https://github.com/pinellolab/stormi/commit/6153350542c2f18586c78046cad6c7c265864b4d))
